@@ -5,10 +5,12 @@ import logging
 import shutil
 import time
 from datetime import datetime
+from functools import partial
 from pathlib import Path
 
 from dateutil.relativedelta import relativedelta
 
+from road_data_scraper import TMP_LOG_PATH
 from road_data_scraper.report.report import run_reports
 from road_data_scraper.steps.download import THREAD_POOL, download
 from road_data_scraper.steps.file_handler import (
@@ -16,18 +18,20 @@ from road_data_scraper.steps.file_handler import (
     file_handler,
     gcp_upload_from_directory,
 )
-from road_data_scraper.steps.metadata import get_site_urls, get_sites_by_sensor
+from road_data_scraper.steps.metadata import get_sensor_urls, get_sites_by_sensor
 
-logging.basicConfig(
-    format="%(asctime)s.%(msecs)03d %(levelname)-8s %(message)s",
-    level=logging.INFO,
-    datefmt="%Y-%m-%d %H:%M:%S",
-    handlers=[logging.StreamHandler()],
-)
+LOGGER = logging.getLogger(__name__)
 
 
-def run(config, api_run):
+def run(config: dict, api_run: bool):
+    """
+    Runs the Pipeline to Scrape Road Traffic Sensor Data
+    from Highways England WebTRIS API.
 
+    Args:
+        config (dict): Configuration file for this run.
+        api_run (bool): True if using FastAPI for this run.
+    """
     start_time = time.time()
 
     if api_run:
@@ -59,58 +63,39 @@ def run(config, api_run):
         config, api_run, start_date, end_date
     )
 
-    logging.getLogger().addHandler(
-        logging.FileHandler(f"{metadata_path}/road_data_pipeline.log")
-    )
-
-    logging.info(f"Using {THREAD_POOL} threads")
+    LOGGER.info(f"Using {THREAD_POOL} threads")
 
     test_run = my_ast(config["user_settings"]["test_run"])
     generate_report = my_ast(config["user_settings"]["generate_report"])
 
-    logging.info("Getting Road Sensor Lookup Table")
+    LOGGER.info("Getting Road Sensor Lookup Table")
 
     sensor_tables, lookup_df = get_sites_by_sensor()
     lookup_df.to_csv(f"{str(metadata_path)}/road_data_sensor_lookup.csv", index=False)
 
-    midas_metadata, tmu_metadata, tame_metadata = get_site_urls(
+    midas_metadata, tmu_metadata, tame_metadata = get_sensor_urls(
         sensor_tables, start_date, end_date
     )
 
-    logging.info("Processed Road Sensor Lookup Table")
+    LOGGER.info("Processed Road Sensor Lookup Table")
 
     if test_run:
-        logging.info("Test Run")
+        LOGGER.info("Test Run")
         midas_metadata = midas_metadata[1:2]
         tmu_metadata = tmu_metadata[1:2]
         tame_metadata = tame_metadata[1:2]
 
-    download(
-        site_name="midas",
+    download_partial = partial(
+        download,
         start_date=start_date,
         end_date=end_date,
-        metadata=midas_metadata,
         test_run=test_run,
         run_id_path=data_path,
     )
 
-    download(
-        site_name="tmu",
-        start_date=start_date,
-        end_date=end_date,
-        metadata=tmu_metadata,
-        test_run=test_run,
-        run_id_path=data_path,
-    )
-
-    download(
-        site_name="tame",
-        start_date=start_date,
-        end_date=end_date,
-        metadata=tame_metadata,
-        test_run=test_run,
-        run_id_path=data_path,
-    )
+    download_partial(site_name="midas", metadata=midas_metadata)
+    download_partial(site_name="tmu", metadata=tmu_metadata)
+    download_partial(site_name="tame", metadata=tame_metadata)
 
     if generate_report:
         run_reports(lookup_df, report_path, start_date, end_date)
@@ -120,24 +105,23 @@ def run(config, api_run):
     else:
         dump_config(config, metadata_path, api_run=False)
 
-    logging.info(f"Script Run Time: {round((time.time() - start_time)/60, 2)} minutes")
+    LOGGER.info(f"Script Run Time: {round((time.time() - start_time)/60, 2)} minutes")
+
+    log_file_path = f"{metadata_path}/road_data_pipeline.log"
+    shutil.copyfile(TMP_LOG_PATH, log_file_path)
 
     gcp_storage = my_ast(config["user_settings"]["gcp_storage"])
-
     if gcp_storage:
-
-        gcp_bucket_name = my_ast(config["user_settings"]["gcp_bucket_name"])
-        gcp_folder_name = my_ast(config["user_settings"]["gcp_blob_name"])
-        gcp_credentials = my_ast(config["user_settings"]["gcp_credentials"])
-
         gcp_upload_from_directory(
-            run_id_path, gcp_bucket_name, gcp_folder_name, gcp_credentials
+            run_id_path,
+            gcp_bucket_name=my_ast(config["user_settings"]["gcp_bucket_name"]),
+            gcp_folder_name=my_ast(config["user_settings"]["gcp_blob_name"]),
+            gcp_credentials=my_ast(config["user_settings"]["gcp_credentials"]),
         )
 
     rm_dir = my_ast(config["user_settings"]["rm_dir"])
-
     if rm_dir:
-        logging.info(
+        LOGGER.info(
             f"Removing {run_id_path[run_id_path.find('output_data/'):].split('/')[1]} folder"
         )
         shutil.rmtree(Path(run_id_path))
@@ -148,4 +132,4 @@ if __name__ == "__main__":
     config = configparser.ConfigParser()
     config.read("./config.ini")
 
-    run(config)
+    run(config, api_run=False)
